Index: src/uk/me/parabola/mkgmap/reader/osm/Element.java
===================================================================
--- src/uk/me/parabola/mkgmap/reader/osm/Element.java	(revision 1001)
+++ src/uk/me/parabola/mkgmap/reader/osm/Element.java	(working copy)
@@ -18,6 +18,9 @@
 import java.util.Collections;
 import java.util.Iterator;
 
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
+
 /**
  * Superclass of the node, segment and way OSM elements.
  */
@@ -94,7 +97,79 @@
 	}
 
 	public void setName(String name) {
-		if (this.name == null)
+		if (this.name == null) {
+
 			this.name = name;
+
+			// Symbols for highway graphics (8-bit):
+
+			char sSymbMotorway = (char)0x04;
+			char sSymbHighwayLarge = (char)0x05;
+			char sSymbHighwaySmall = (char)0x06;
+
+			final String magicSet = "^[" + sSymbMotorway + sSymbHighwayLarge + sSymbHighwaySmall + "]";
+			final String magicName = magicSet +  ".*";
+
+				
+			// Found magic char
+			if (name != null && name.matches(magicName)) {
+
+				System.out.println("Magic char: " + name);
+
+			   
+				// Reject unreasonable strings
+				if (name.matches("^.\\S{8,}.*") // 8 or more chars without a space
+				   || name.matches("^.\\D{5,}.*") // 5 or more chars without numeric
+				   || name.matches("^.\\D{3,}") // 3 or more exclusively non-numeric chars
+				) {
+
+					Pattern patReject = Pattern.compile(magicSet + "(.*)");
+					Matcher matcherReject = patReject.matcher(name);
+
+					if (matcherReject.find()) {
+						this.name = matcherReject.group(1);
+						System.out.println("* Rejected");
+					}
+
+
+				// Remove spaces in reference.
+				// Changes "A 1" to "A1", "SS 123" to "SS123", etc.
+				// Needed because the graphic will only display characters up to the first space.
+				// ("A 1" would be displayed as only "A" in the graphic.)
+				} else {
+
+					// Change "B 12;B 13" -> "B12;B13"
+					Pattern pat = Pattern.compile("(^.\\D{1,4})\\s+(\\d+;\\D{1,4})\\s+(\\d+.*)");
+					Matcher matcher = pat.matcher(name);
+					
+					if (matcher.find()) {
+
+						this.name = matcher.group(1) + matcher.group(2) + matcher.group(3);
+
+						System.out.println("No space: " + this.name);
+
+					} else {
+
+						// Normal conversion "B 12" -> "B12"
+						pat = Pattern.compile("(^.\\D{1,4})\\s+(\\d+.*)");
+						matcher = pat.matcher(name);
+					
+						if (matcher.find()) {
+
+							this.name = matcher.group(1) + matcher.group(2);
+
+							System.out.println("No space: " + this.name);
+
+						}
+
+					}
+
+				}
+
+
+								
+			}
+
+		}
 	}
 }
